@@ -138,6 +138,8 @@ class Invoice(models.Model):
                              blank=True, null=True, default=None)
     date_paid = MonitorField(monitor='status', when=[STATUS.PAID], verbose_name=_(u'date paid'),
                              blank=True, null=True, default=None)
+    date_reminder_sent = models.DateTimeField(verbose_name=_(u'date reminder sent'),
+                                              blank=True, null=True, default=None)
 
     # Payment details
     currency = models.CharField(_(u'currency'), max_length=10, choices=CURRENCY_CHOICES)
@@ -450,6 +452,9 @@ class Invoice(models.Model):
         sum = 0
         for item in self.item_set.all():
             sum += item.subtotal
+
+        sum -= Decimal(self.credit)  # subtract credit
+
         return round(sum, 2)
 
     @property
@@ -466,7 +471,7 @@ class Invoice(models.Model):
 
     @property
     def total_without_discount(self):
-        return float(self.total) + self.discount
+        return Decimal(self.total) + self.discount
 
     def calculate_vat(self):
         if len(self.vat_summary) == 1 and self.vat_summary[0]['vat'] is None:
@@ -523,7 +528,7 @@ class Item(models.Model):
         verbose_name_plural = _(u'items')
         ordering = ('-invoice', 'weight', 'created')
 
-    def __unicode__(self):
+    def __str__(self):
         return self.title
 
     def get_absolute_url(self):
